@@ -1,9 +1,14 @@
 package SSIS::Package::ConnectionManager;
 
 use 5.010;
-use Mouse;
+use strict;
+use warnings;
+use XML::Simple ; #qw(:strict);
+#use XML::LibXML;
+use XML::CompactTree::XS;
+use XML::LibXML::Reader;
+
 
-use Carp;
 
 =head1 NAME
 
@@ -11,51 +16,46 @@ SSIS::Package::ConnectionManager - Base class for SSIS package connection manage
 
 =head1 VERSION
 
-Version 0.04
+Version 0.01
 
 =cut
 
-#use autodie qw(:all);
+our $VERSION = '0.01';
+
+
+use autodie qw(:all);
 
 #TODO 0. 
 
+use Data::Dumper ;
+use Carp ;
 
-has 'CreationName' => (
-    is  => 'ro'
-,   isa => 'Str'
-,   required => 1
-);
+sub new {
 
-has 'ObjectName' => (
-    is  => 'ro'
-,   isa => 'Str'
-,   required => 1
-);
+    local $_ ;
 
-has 'DelayValidation' => (
-    is  => 'ro'
-,   isa => 'Num'
-,   required => 1
-);
+    my $invocant         = shift ;
+    my $class            = ref($invocant) || $invocant ;
 
-has 'Description' => (
-    is  => 'ro'
-,   isa => 'Maybe[Str]'
-,   required => 1
-);
+    my @elems            = @_ ;
+    my $self             = bless {}, $class ;
 
-has 'DTSID' => (
-    is  => 'ro'
-,   isa => 'Str'
-,   required => 1
-);
+    $self->_init(@elems) ;
+    
+    return $self ;
+}
 
-has 'ConnectionString' => (
-    is  => 'ro'
-,   isa => 'Maybe[Str]'
-,   required => 0
-);
 
+sub _init {
+
+    local $_ ;
+
+    my $self                = shift ;
+    my $class               = ref($self) || $self ;
+
+    return ;
+
+}
 
 
 
